import json

from django.conf import settings
from django.core.mail import send_mail
from django.core.management import call_command
from django.http import HttpResponse
from django.views.generic.base import View
from singular_dbbackup_sender.database_backup import generate_backup


class PushRequest(View):
    def post(self, *args, **kwargs):
        status = 200
        email_message = 'Server updated successfully!'
        try:
            body = json.loads(self.request.body.decode('utf-8'))
            branch_name = body['push']['changes'][0]['new']['name']
            if branch_name == settings.SERVER_BRANCH:
                server_settings = settings.SERVER_SETTINGS
                generate_backup()
                call_command('update_server', server_settings['PROJECT_NAME'], server_settings['HOST'],
                             server_settings['USER'], server_settings['PASSWORD'],
                             server_settings['GIT_PASSWORD'], server_settings.get('HAS_WEBSOCKETS', False),
                             server_settings.get('HAS_CRONJOBS', False))
        except Exception as e:
            status = 500
            email_message = str(e)
        finally:
            send_mail('Server update status', email_message, settings.DEFAULT_FROM_EMAIL, settings.ADMINS)
        return HttpResponse(status=status)



import setuptools

setuptools.setup(
    name='singular_server_updater',
    version='0.0.6',
    author='Singular Sistemas',
    author_email='ivan@singular.inf.br',
    description='Server updater',
    long_description='Server updater',
    url='https://lucas@bitbucket.org/singular-dev/server_updater.git',
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
    install_requires=[
        'django',
        'fabric',
        'invoke',
        'django-crontab',
        'singular_dbbackup_sender'
    ]
)
